@@ -27,7 +27,7 @@ import click
 from click import echo, style, secho, getchar
 from click.termui import strip_ansi
 
-__version__ = '2.2.0'
+__version__ = '2.2.1'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -180,7 +180,7 @@ def get_current_git_branch():
     try:
         proc = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         out, _ = proc.communicate()
-        return out.strip()
+        return out.strip().decode('utf-8')
     except subprocess.CalledProcessError:
         pass
     return ''
@@ -193,6 +193,7 @@ R_ARROW = TermString('➔')
 DOLLAR = TermString('$')
 PERCENT = TermString('%')
 
+
 def get_prompt_state():
     full_cwd = os.getcwd()
     cwd_raw = full_cwd.replace(env['HOME'], '~')
@@ -267,6 +268,7 @@ def run_command(cmd, shell=None, aliases=None, envvars=None, test_mode=False):
             else:
                 return subprocess.call([shell, fp.name])
 
+
 def wait_for(chars):
     while True:
         in_char = getchar()
@@ -318,6 +320,7 @@ def echo_prompt(template):
 # Exceptions
 # ##########
 
+
 class DoItLiveError(Exception):
     """Base exception class for all doitlive-related errors."""
     pass
@@ -451,6 +454,7 @@ OPTION_MAP = {
     'unset': lambda state, arg: state.remove_envvar(arg),
 }
 
+
 def run(commands, shell='/bin/bash', prompt_template='default', speed=1,
         test_mode=False):
     secho("We'll do it live!", fg='red', bold=True)
